var $j = jQuery.noConflict();

$j(function(){
    var AccessibilityWidget = {
	/* cookies methods */
	setCookie : function(name, value, days){
            var expires = "";
	    if (days) {
		var date = new Date();
		date.setTime(date.getTime()+(days*24*60*60*1000));
		expires = "; expires="+date.toGMTString();
	    }
	    document.cookie = 'Accessibility_'+name+'='+value+expires+'; path=/';
	},
	getCookie : function(name){
	    var nameEQ = 'Accessibility_'+name + "=";
	    var ca = document.cookie.split(';');
	    for(var i=0;i < ca.length;i++) {
		var c = ca[i];
		while (c.charAt(0)==' ') c = c.substring(1,c.length);
		if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);
	    }
	    return null;
	},
	deleteCookie : function(name){
	    AccessibilityWidget.setCookie(name, '', -1);
	},

	/* fonts cookie methods */
	getCookieFontSize : function(){
	    return AccessibilityWidget.getCookie('font-size');
	},
	setCookieFontSize : function(size){
	    AccessibilityWidget.setCookie('font-size', size);
	},
	deleteCookieFontSize : function(){
	    AccessibilityWidget.deleteCookie('font-size');
	},

	/* fonts methods */
	getFontSize : function(){
	    return parseFloat($j('body').css('font-size'), 10);
	},
	setFontSize : function(fontSize){
	    fontSize = (isNaN(fontSize))?fontSize:Math.round(fontSize);
	    fontSize = (fontSize==undefined || fontSize<=0)?'':fontSize;
	    $j('body').css('font-size', fontSize);
	    AccessibilityWidget.setCookieFontSize(AccessibilityWidget.getFontSize());
	},
	increaseFontSize : function(){
	    AccessibilityWidget.setFontSize(AccessibilityWidget.getFontSize()*1.1);
	},
	decreaseFontSize : function(){
	    AccessibilityWidget.setFontSize(AccessibilityWidget.getFontSize()*0.9);
	},
	resetFontSize : function(){
	    AccessibilityWidget.setFontSize();
	    AccessibilityWidget.deleteCookieFontSize();
	},

	/* high contrast cookie methods */
	getCookieHighContrast : function(){
            $j("body").data('high-contrast', AccessibilityWidget.getCookie('high-contrast'));
	    return $j("body").data('high-contrast');
	},
	setCookieHighContrast : function(value){
            $j(".accessibility-bar .button").removeClass('enabled');
            $j("body").data('high-contrast', value);
	    AccessibilityWidget.setCookie('high-contrast', value);
            $j(".accessibility-bar #"+value).addClass('enabled');
	},
	deleteCookieHighContrast : function(){
            $j(".accessibility-bar .button").removeClass('enabled');
            $j("body").data('high-contrast', null);
            $j(".accessibility-bar #normal-standard").addClass('enabled')
	    AccessibilityWidget.deleteCookie('high-contrast');
	},

	/* high contrast methods */
	isInHighContrast : function(value){
	    return ($j("body").data('high-contrast')!=null);
	},
	enableHighContrast : function(value){
	    $j("body").removeClass($j("body").data('high-contrast')).addClass('high-contrast').addClass(value);
	    AccessibilityWidget.setCookieHighContrast(value);
	},
	disableHighContrast : function(){
	    $j("body").removeClass('high-contrast').removeClass($j("body").data('high-contrast'));
	    AccessibilityWidget.deleteCookieHighContrast();
	},

	/* justify cookie methods */
	getCookieJustify : function(){
	    return AccessibilityWidget.getCookie('justify');
	},
	setCookieJustify : function(){
	    AccessibilityWidget.setCookie('justify', 'enable');
	},
	deleteCookieJustify : function(){
	    AccessibilityWidget.deleteCookie('justify');
	},

	/* justify methods */
	isJustified : function(){
	    return ($j("body").css('text-align')=='justify');
	},
	enableJustify : function(){
	    $j("body").addClass('justify');
            $j("body").css({'text-align':'justify'});
            $j(".accessibility-bar .button.justify").attr('title', AccessibilityBarDomain.disableTextJustification);
	    AccessibilityWidget.setCookieJustify();
	},
	disableJustify : function(){
	    $j("body").removeClass('justify');
            $j("body").css({'text-align':''});
            $j(".accessibility-bar .button.justify").attr('title', AccessibilityBarDomain.enableTextJustification);
	    AccessibilityWidget.deleteCookieJustify();
	},
	toggleJustify : function(){
	    //$j("body").toggleClass('justify');
	    if(!AccessibilityWidget.isJustified()){
		AccessibilityWidget.enableJustify();
	    }else{
		AccessibilityWidget.disableJustify();
	    }
	},

	/* initialization method */
	init : function(){
            /* Show the javascript dependent buttons */
            $j("body").css({'transition-duration':'0.5s'});
            $j(".accessibility-bar .button.hide-if-no-js").css({'display':'block'});
            
	    /* Restore the font size */
	    var fontSize = AccessibilityWidget.getCookieFontSize();
	    if(fontSize){
		AccessibilityWidget.setFontSize(fontSize);
	    }

	    /* Restore the high contrast */
	    var highContrast = AccessibilityWidget.getCookieHighContrast();
	    if(highContrast){
		AccessibilityWidget.enableHighContrast(highContrast);
	    }else{
                AccessibilityWidget.disableHighContrast();
            }

	    /* Restore the justify state */
	    var justify = AccessibilityWidget.getCookieJustify();
	    if(justify){
		AccessibilityWidget.enableJustify();
	    }else{
                AccessibilityWidget.disableJustify();
            }

	    /* buttons handlers */
	    $j(".accessibility-bar .zoom-in").click(function(e){
		AccessibilityWidget.increaseFontSize();
                e.preventDefault();
		return false;
	    });
            
	    $j(".accessibility-bar .zoom-out").click(function(e){
		AccessibilityWidget.decreaseFontSize();
                e.preventDefault();
		return false;
	    });
	    $j(".accessibility-bar .zoom-reset").click(function(e){
		AccessibilityWidget.resetFontSize();
                e.preventDefault();
		return false;
	    });
	    $j(".accessibility-bar .high-contrast:not(#normal-standard)").click(function(e){
		AccessibilityWidget.enableHighContrast($j(this).attr('id'));
		return false;
	    });
            
            $j(".accessibility-bar #normal-standard").click(function(e){
		AccessibilityWidget.disableHighContrast();
                e.preventDefault();
		return false;
	    });
	    $j(".accessibility-bar .justify").click(function(e){
		AccessibilityWidget.toggleJustify();
                e.preventDefault();
		return false;
	    });
	    
	    $j(".accessibility-bar").live('selectstart dragstart', function(evt){evt.preventDefault();return false;});
	}
    };
    AccessibilityWidget.init();
});